==> mule-tooling-bootstrap-1.2.1-sources.jar: org/mule/tooling/client/bootstrap/internal/wrapper/ExtensionModelServiceWrapper.java <==
/*
 * Copyright (c) MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
 * The software in this package is published under the terms of the CPAL v1.0
 * license, a copy of which has been included with this distribution in the
 * LICENSE.txt file.
 */

package org.mule.tooling.client.bootstrap.internal.wrapper;

import static java.util.Objects.requireNonNull;
import org.mule.tooling.client.api.descriptors.ArtifactDescriptor;
import org.mule.tooling.client.api.extension.ExtensionModelService;
import org.mule.tooling.client.api.extension.model.ExtensionModel;
import org.mule.tooling.client.bootstrap.internal.reflection.Dispatcher;
import org.mule.tooling.client.internal.serialization.Serializer;

import com.google.common.collect.ImmutableList;

import java.io.File;
import java.util.List;
import java.util.Optional;

/**
 * Client side implementation for {@link ExtensionModelService} that uses reflection and works as a bridge
 * between {@link ClassLoader classLoaders}.
 *
 * @since 1.0
 */
public class ExtensionModelServiceWrapper implements ExtensionModelService {

  private Dispatcher dispatcher;
  private Serializer serializer;

  public ExtensionModelServiceWrapper(Dispatcher dispatcher, Serializer serializer) {
    requireNonNull(dispatcher, "dispatcher cannot be null");
    requireNonNull(serializer, "serializer cannot be null");

    this.dispatcher = dispatcher;
    this.serializer = serializer;
  }

  @Override
  public Optional<ExtensionModel> loadExtensionModel(ArtifactDescriptor pluginDescriptor) {
    String result = (String) dispatcher.dispatchRemoteMethod("loadExtensionModel",
                                                             ImmutableList.of(ArtifactDescriptor.class),
                                                             ImmutableList.of(serializer.serialize(pluginDescriptor)));
    return serializer.deserialize(result);
  }

  @Override
  public Optional<ExtensionModel> loadExtensionModel(File plugin) {
    String result = (String) dispatcher.dispatchRemoteMethod("loadExtensionModel",
                                                             ImmutableList.of(File.class),
                                                             ImmutableList.of(serializer.serialize(plugin)));
    return serializer.deserialize(result);
  }

  @Override
  public Optional<String> loadExtensionSchema(ArtifactDescriptor pluginDescriptor) {
    String result = (String) dispatcher.dispatchRemoteMethod("loadExtensionSchema",
                                                             ImmutableList.of(ArtifactDescriptor.class),
                                                             ImmutableList.of(serializer.serialize(pluginDescriptor)));
    return serializer.deserialize(result);
  }

  @Override
  public Optional<String> loadExtensionSchema(File plugin) {
    String result = (String) dispatcher.dispatchRemoteMethod("loadExtensionSchema",
                                                             ImmutableList.of(File.class),
                                                             ImmutableList.of(serializer.serialize(plugin)));
    return serializer.deserialize(result);
  }

  @Override
  public List<ExtensionModel> loadMuleExtensionModels() {
    String result = (String) dispatcher.dispatchRemoteMethod("loadMuleExtensionModels");
    return serializer.deserialize(result);
  }

}

==> mule-tooling-bootstrap-1.5.0-rc1-sources.jar: org/mule/tooling/client/bootstrap/internal/wrapper/ExtensionModelServiceWrapper.java <==
/*
 * Copyright (c) MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
 * The software in this package is published under the terms of the CPAL v1.0
 * license, a copy of which has been included with this distribution in the
 * LICENSE.txt file.
 */

package org.mule.tooling.client.bootstrap.internal.wrapper;

import static java.util.Objects.requireNonNull;
import org.mule.tooling.client.api.descriptors.ArtifactDescriptor;
import org.mule.tooling.client.api.extension.ExtensionModelService;
import org.mule.tooling.client.api.extension.model.ExtensionModel;
import org.mule.tooling.client.bootstrap.internal.reflection.Dispatcher;
import org.mule.tooling.client.internal.serialization.Serializer;

import com.google.common.collect.ImmutableList;

import java.io.File;
import java.util.List;
import java.util.Optional;

/**
 * Client side implementation for {@link ExtensionModelService} that uses reflection and works as a bridge between
 * {@link ClassLoader classLoaders}.
 *
 * @since 1.0
 */
public class ExtensionModelServiceWrapper implements ExtensionModelService {

  private Dispatcher dispatcher;
  private Serializer serializer;

  public ExtensionModelServiceWrapper(Dispatcher dispatcher, Serializer serializer) {
    requireNonNull(dispatcher, "dispatcher cannot be null");
    requireNonNull(serializer, "serializer cannot be null");

    this.dispatcher = dispatcher;
    this.serializer = serializer;
  }

  @Override
  public Optional<ExtensionModel> loadExtensionModel(ArtifactDescriptor pluginDescriptor) {
    String result = (String) dispatcher.dispatchRemoteMethod("loadExtensionModel",
                                                             ImmutableList.of(ArtifactDescriptor.class),
                                                             ImmutableList.of(serializer.serialize(pluginDescriptor)));
    return serializer.deserialize(result);
  }

  @Override
  public Optional<ExtensionModel> loadExtensionModel(File plugin) {
    String result = (String) dispatcher.dispatchRemoteMethod("loadExtensionModel",
                                                             ImmutableList.of(File.class),
                                                             ImmutableList.of(serializer.serialize(plugin)));
    return serializer.deserialize(result);
  }

  @Override
  public Optional<String> loadExtensionSchema(ArtifactDescriptor pluginDescriptor) {
    String result = (String) dispatcher.dispatchRemoteMethod("loadExtensionSchema",
                                                             ImmutableList.of(ArtifactDescriptor.class),
                                                             ImmutableList.of(serializer.serialize(pluginDescriptor)));
    return serializer.deserialize(result);
  }

  @Override
  public Optional<String> loadExtensionSchema(File plugin) {
    String result = (String) dispatcher.dispatchRemoteMethod("loadExtensionSchema",
                                                             ImmutableList.of(File.class),
                                                             ImmutableList.of(serializer.serialize(plugin)));
    return serializer.deserialize(result);
  }

  @Override
  public List<ExtensionModel> loadMuleExtensionModels() {
    String result = (String) dispatcher.dispatchRemoteMethod("loadMuleExtensionModels");
    return serializer.deserialize(result);
  }

}
